@@ -1,19 +1,24 @@
-import flask
-from flask import request, render_template, flash, redirect, url_for
-from flask_login import login_user
-
+from ..auth_provider import KnowledgeAuthProvider
 from ..models import User
 from ..utils.auth import is_safe_url
-
-from ..auth_provider import KnowledgeAuthProvider
+from flask import (
+    flash,
+    redirect,
+    render_template,
+    request,
+    url_for,
+)
+from flask_login import login_user
+from knowledge_repo.constants import AUTH_LOGIN_FORM, DEBUG, USERNAME
+import flask
 
 
 class DebugAuthProvider(KnowledgeAuthProvider):
-    _registry_keys = ['debug']
+    _registry_keys = [DEBUG]
 
     def prompt(self):
         if request.method == 'POST':
-            user = request.form['username']
+            user = request.form[USERNAME]
             login_user(User(identifier=user))
 
             flash('Logged in successfully.')
@@ -25,7 +30,7 @@ class DebugAuthProvider(KnowledgeAuthProvider):
                 return flask.abort(400)
 
             return redirect(next or url_for('index.render_feed'))
-        return render_template('auth-login-form.html', skip_password=True)
+        return render_template(AUTH_LOGIN_FORM, skip_password=True)
 
     def get_user(self):
-        return User(identifier=request.form['username'])
+        return User(identifier=request.form[USERNAME])
