@@ -29,7 +29,7 @@ PRESETS = {
         'scopes': None,
         'user_info_endpoint': 'user',
         'user_info_mapping': {
-            'identifier': ['email', 'login'],
+            'identifier': ['login'],
             'name': 'name',
             'avatar_uri': 'avatar_url'
         }
@@ -41,7 +41,8 @@ PRESETS = {
         'auto_refresh_url': 'https://accounts.google.com/o/oauth2/token',
         'scopes': [
             'https://www.googleapis.com/auth/userinfo.email',
-            'https://www.googleapis.com/auth/userinfo.profile'
+            'https://www.googleapis.com/auth/userinfo.profile',
+            'openid'
         ],
         'user_info_endpoint': 'userinfo',
         'user_info_mapping': {
