@@ -1,6 +1,7 @@
 from alembic import context
-from sqlalchemy import engine_from_config, pool
+from flask import current_app
 from logging.config import fileConfig
+from sqlalchemy import engine_from_config, pool
 import logging
 
 # this is the Alembic Config object, which provides
@@ -14,8 +15,6 @@ logger = logging.getLogger('alembic.env')
 
 # add your model's MetaData object here
 # for 'autogenerate' support
-from flask import current_app
-
 config.set_main_option('sqlalchemy.url',
                        current_app.config.get('SQLALCHEMY_DATABASE_URI'))
 target_metadata = current_app.db.metadata
@@ -38,7 +37,7 @@ def run_migrations_offline():
     script output.
 
     """
-    url = config.get_main_option("sqlalchemy.url")
+    url = config.get_main_option('sqlalchemy.url')
     context.configure(url=url)
 
     with context.begin_transaction():
@@ -79,6 +78,7 @@ def run_migrations_online():
     finally:
         connection.close()
 
+
 if context.is_offline_mode():
     run_migrations_offline()
 else:
