@@ -20,6 +20,8 @@ from flask import (
     redirect,
     render_template,
     request,
+    send_from_directory,
+    url_for,
 )
 from flask_login import login_required
 from sqlalchemy import case, desc
@@ -49,6 +51,36 @@ def site_map():
     return '<br />'.join(str(link) for link in links)
 
 
+@blueprint.route("/robots.txt")
+@PageView.logged
+def robots_txt():
+    return send_from_directory(current_app.static_folder, request.path[1:])
+
+
+@blueprint.route("/site-map.xml")
+@PageView.logged
+def site_map_posts():
+    posts = db_session.query(Post).filter(Post.is_published)
+    values = []
+    # [TODO]handle https with deployed with action gateway
+    app_domain = request.url_root.replace("http", "https")
+    for post in posts:
+        values.append(
+            {
+                "loc": "{app_domain}post/{post_path}".format(
+                    app_domain=app_domain,
+                    post_path=post.path
+                ),
+                "lastmod": post.updated_at.strftime("%Y-%m-%dT%H:%M:%S+00:00"),
+                "priority": 1
+            }
+        )
+    template = render_template('sitemap.xml', values=values)
+    response = make_response(template)
+    response.headers['Content-Type'] = 'application/xml'
+    return response
+
+
 @blueprint.route('/')
 @PageView.logged
 def render_index():
