@@ -22,11 +22,11 @@
             // Compute height of nested (and potentially masked elements) elements
             var height = $(tldr).children().map(function (undefined, elem) { return $(elem).outerHeight() + 5; }).toArray().reduce(function (prev, curr) { return prev + curr; }, 0);
 
-            $(tldr).animate({ "height": Math.max(height + 25, em_to_px(this, 5) + 5) }, 400);
+            $(tldr).animate({ "height": Math.max(height + 25, em_to_px(this, 1.5) + 5) }, 400);
             $(tldr).data('expanded', true);
             $(this).html('<a>- Show Less</a>');
         } else {
-            $(tldr).animate({ "height": em_to_px(this, 5) + 5 }, 400);
+            $(tldr).animate({ "height": em_to_px(this, 1.5) + 5 }, 400);
             $(tldr).data('expanded', false);
             $(this).html('<a>+ Show More</a>');
         }
