@@ -1,15 +1,16 @@
+from ..constants import EXTRACT_IMAGES
+from ..postprocessor import KnowledgePostProcessor
+from knowledge_repo.utils.files import read_binary
+import logging
 import os
 import posixpath
 import re
-import logging
-
-from ..postprocessor import KnowledgePostProcessor
 
 logger = logging.getLogger(__name__)
 
 
 class ExtractImages(KnowledgePostProcessor):
-    _registry_keys = ['extract_images']
+    _registry_keys = [EXTRACT_IMAGES]
 
     def process(self, kp):
         images = self.find_images(kp.read())
@@ -20,7 +21,8 @@ class ExtractImages(KnowledgePostProcessor):
     def update_thumbnail_uri(self, kp, images, image_mapping):
         thumbnail = kp.headers.get('thumbnail', 0)
 
-        # if thumbnail is a number, select the nth image in this post as the thumbnail
+        # if thumbnail is a number, select the nth image in this post
+        # as the thumbnail
         if isinstance(thumbnail, str) and thumbnail.isdigit():
             thumbnail = int(thumbnail)
         if isinstance(thumbnail, int):
@@ -32,15 +34,18 @@ class ExtractImages(KnowledgePostProcessor):
             else:
                 thumbnail = None
 
-        # if thumbnail is a url, copy it locally to the post unless already collected during collection
+        # if thumbnail is a url, copy it locally to the post unless already
+        # collected during collection
         if thumbnail and not self.skip_image(kp, {'src': thumbnail}):
-            orig_path = os.path.join(kp.orig_context, os.path.expanduser(thumbnail))
+            orig_path = os.path.join(
+                kp.orig_context, os.path.expanduser(thumbnail))
             if thumbnail in image_mapping:
                 thumbnail = image_mapping[thumbnail]
             elif os.path.exists(orig_path):
                 thumbnail = self.copy_image(kp, orig_path)
             else:
-                logger.warning("Could not find a thumbnail image at: {}".format(thumbnail))
+                logger.warning(
+                    f'Could not find a thumbnail image at: {thumbnail}')
 
         # update post headers to point to new thumbnail image
         kp.update_headers(thumbnail=thumbnail)
@@ -49,16 +54,19 @@ class ExtractImages(KnowledgePostProcessor):
         images = []
         images.extend(self.collect_images_for_pattern(
             md,
-            # Match all <img /> tags with attributes of form <name>(="<value>") with optional quotes (can be single or double)
+            # Match all <img /> tags with attributes of form <name>(="<value>")
+            # with optional quotes (can be single or double)
             # The src attribute is exected to always be surrounded by quotes.
             r'<img\s+(?:\w+(?:=([\'\"])?(?(1)(?:(?!\1).)*?\1|[^>]*?))?\s+?)*src=([\'\"])(?P<src>(?:(?!\2).)*?)\2(?:\s+\w+(?:=([\'\"])?(?(1)(?:(?!\4).)*?\4|[^>]*?))?)*\s*\/?>'
         ))
-        images.extend(self.collect_images_for_pattern(md, r'\!\[[\s\S]*?\]\((?P<src>[^\)]*)\)'))
+        images.extend(self.collect_images_for_pattern(
+            md, r'\!\[[^\]]*?\]\((?P<src>[^\)]*)\)'))
         return sorted(images, key=lambda x: x['offset'])
 
     def collect_images_for_pattern(self, md, pattern=None):
         p = re.compile(pattern)
-        return [{'offset': m.start(), 'tag': m.group(0), 'src': m.group('src')} for m in p.finditer(md)]
+        return [{'offset': m.start(), 'tag': m.group(0), 'src': m.group('src')}
+                for m in p.finditer(md)]
 
     def collect_images(self, kp, images):
         image_mapping = {}
@@ -69,7 +77,8 @@ class ExtractImages(KnowledgePostProcessor):
         for image in images:
             if self.skip_image(kp, image):
                 continue
-            orig_path = os.path.join(kp.orig_context, os.path.expanduser(image['src']))
+            orig_path = os.path.join(
+                kp.orig_context, os.path.expanduser(image['src']))
             new_path = None
             if image['src'] in image_mapping:
                 new_path = image_mapping[image['src']]
@@ -78,26 +87,28 @@ class ExtractImages(KnowledgePostProcessor):
             elif os.path.exists(orig_path):
                 new_path = self.copy_image(kp, orig_path)
             else:
-                logger.warning("Could not find an image at: {}".format(image['src']))
+                image_src = image['src']
+                logger.warning(f'Could not find an image at: {image_src}')
             if not new_path:
                 continue
             image_mapping[image['src']] = new_path
-            md = self.replace_image_locations(md, image['offset'], image['tag'], image['src'], new_path)
+            md = self.replace_image_locations(
+                md, image['offset'], image['tag'], image['src'], new_path)
         kp.write(md)
         return image_mapping
 
     def skip_image(self, kp, image):
         if re.match('http[s]?://', image['src']):
             return True
-        if image['src'].startswith('images/') and image['src'] in kp.image_paths:
+        if image['src'].startswith('images/') and \
+                image['src'] in kp.image_paths:
             return True
         return False
 
     def copy_image(self, kp, path, is_ref=False):
         if is_ref:
             return
-        with open(path, 'rb') as f:
-            kp.write_image(os.path.basename(path), f.read())
+        kp.write_image(os.path.basename(path), read_binary(path))
         return posixpath.join('images', os.path.basename(path))
 
     def replace_image_locations(self, md, offset, match, old_path, new_path):
